
 # Empirical study ----  Change of Interest Rates as a regressor
 rm(list=ls())

 ##### read data and summary
 SP500 = read.csv("SP500Dividend.csv")
 CPI=read.csv("../Figsh/CPI.csv")
 TB03 = read.csv("../Fama-French/tb3m.txt",skip=10)

 SPY  = SP500[,2]*CPI[1:1560,2]/CPI[1562,2]    

 					 #unadjusted inflation 


 
 
 ######## Computation of changes of 3 month rates ########
 tb3m = 0; n = nrow(TB03)
 for(i in 1:12) tb3m = tb3m + TB03[i:(n-12+i),2]
 tb3m = tb3m/12
 tb3m = tb3m[-length(tb3m)]
 tb3m = TB03[13:n,2] - tb3m           #changes in interest rates

 postscript("Fig98.eps", width=4.4, height=3.0, horizontal=F, pointsize=8)
 par(mfrow = c(1, 1), mar=c(2.1, 2.1,1.5,.5)+0.1, cex=0.8)
 tb3m = ts(tb3m, start=c(1935,1), frequency=12)
 plot.ts(tb3m, col=4, lwd=2, xaxt="n")
 labs = c(seq(1940, 2010, by=10))
 axis(1, at=labs, labels=labs)
 abline(0,0, col=2)
 title("Changes of short-term interest rates over previous year")
 dev.off()

 ######### Synchronize the data   ########################
 n = length(tb3m)
 tb3m = tb3m[192:(n-3)]
 SPYr  = diff(log(SPY))[840:1559]
 ##########################################################

 result = array(0, c(3, 6, 3))           #storing the result 
for(case in 1:3)
{               
 period = switch(case,361:720, 1:360, 1:720)
 
 R = SPYr[period]                              #subset of data
 DPratio=tb3m[period]                          # use old code, change of 3 month bill
 n = length(R) 
 
 
 period = c(1, 3, 12, 24, 36, 48)
 

postscript(paste("Fig9", 8+case, ".eps", sep=""), width=4.4, height=4.8, horizontal=F, pointsize=8)
par(mfrow = c(3, 2), mar=c(2.1, 2.1,1.5,.5)+0.1, cex=0.8)

for(j in 1:length(period))
{
################### K period returns ######################
 K = period[j]
 RK  = 0                       
 for(i in 1:K) RK = RK + R[i:(n-K+i)]       # K period returns
  

 DPratio = as.vector(DPratio[1:(n-K+1)])
 
 #######  least squares fit  ##########
 fitted = lsfit(DPratio, RK)
 result[1,j, case] = fitted$coef[2]
 resid = fitted$residuals
 result[2,j,case] = cor(RK, RK-resid)^2          #multiple R^2
 plot(DPratio, RK, pch=20, col=4)
 abline(fitted$coef)
 title(paste(K, "-month horizon", sep=""))
 
 #cor(DPratio, RK)
 ######   Newew and West adjustment #######
 T = length(RK)
 X = cbind(1, DPratio)                           #design matrix
 S =  (t(X) %*% X)/T
 
 Xeps = cbind(resid, resid*DPratio)  

 Sigma = array(0, dim=c(2, 2, K))          #recording cross-mom
 for(i in 0:(K-1))
  {tmp = t(Xeps[1:(T-K+1),]) %*% Xeps[(i+1):(T-K+i+1),] 
   								#cross moments
   Sigma[,,i+1] = tmp + t(tmp)
  }  
 Sigma[,,1] = Sigma[,,1]/2      #adjust for double summation
 

 NW = 0                         #Newey-West estimator
 for(i in 1:K)
    NW = NW + (K-i+1)/K*Sigma[,,i]
 NW = NW/T

 NW = solve(S)%*% NW %*%solve(S)/T
 result[3,j,case] = result[1,j,case]/sqrt(NW[2,2])   #t-test statistics
}
dev.off()
}

round(result,4)

    [,1]    [,2]   [,3]   [,4]    [,5]    [,6]
[1,] -0.0014 -0.0001 0.0057 0.0119 -0.0113 -0.0403
[2,]  0.0017  0.0000 0.0014 0.0031  0.0018  0.0183
[3,] -0.7133 -0.0193 0.2087 0.5717 -0.4337 -1.3833

, , 2

        [,1]    [,2]    [,3]    [,4]    [,5]    [,6]
[1,] -0.0084 -0.0190 -0.0711 -0.0651 -0.0251 -0.0267
[2,]  0.0559  0.0732  0.1652  0.0701  0.0089  0.0088
[3,] -5.0269 -3.8564 -3.4109 -2.1208 -0.9356 -0.8766

, , 3

        [,1]    [,2]    [,3]    [,4]    [,5]    [,6]
[1,] -0.0042 -0.0080 -0.0187 -0.0098 -0.0157 -0.0288
[2,]  0.0154  0.0139  0.0154  0.0023  0.0042  0.0115
[3,] -3.1463 -2.0433 -1.0081 -0.6015 -1.0487 -1.4217

